@@ -23,6 +23,7 @@ import java.util.stream.Stream;
 
 import db.DBRecord;
 import db.StringField;
+import ghidra.program.model.address.*;
 import ghidra.trace.database.DBTrace;
 import ghidra.trace.database.target.CachePerDBTraceObject.Cached;
 import ghidra.trace.database.target.DBTraceObjectValue.ValueLifespanSetter;
@@ -193,6 +194,16 @@ public class DBTraceObject extends DBAnnotatedObject implements TraceObject {
 		}
 	}
 
+	@Override
+	public boolean isAlive(Lifespan span) {
+		try (LockHold hold = manager.trace.lockRead()) {
+			LifeSet result = ensureCachedLife();
+			synchronized (result) {
+				return result.intersects(span);
+			}
+		}
+	}
+
 	protected DBTraceObject doCreateCanonicalParentObject() {
 		return manager.doCreateObject(path.parent());
 	}
@@ -659,6 +670,14 @@ public class DBTraceObject extends DBAnnotatedObject implements TraceObject {
 		}
 	}
 
+	static AddressSpace spaceForValue(Object value) {
+		return switch (value) {
+			case Address address -> address.getAddressSpace();
+			case AddressRange range -> range.getAddressSpace();
+			default -> null;
+		};
+	}
+
 	@Override
 	public TraceObjectValue setValue(Lifespan lifespan, String key, Object value) {
 		return setValue(lifespan, key, value, ConflictResolution.TRUNCATE);
