@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -18,79 +18,36 @@ package ghidra.trace.database.target;
 import static org.junit.Assert.*;
 
 import java.io.File;
+import java.math.BigInteger;
 import java.util.*;
 import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
 import org.junit.Before;
 import org.junit.Test;
 
 import db.Transaction;
 import generic.Unique;
-import ghidra.dbg.target.schema.SchemaContext;
-import ghidra.dbg.target.schema.TargetObjectSchema.SchemaName;
-import ghidra.dbg.target.schema.XmlSchemaContext;
-import ghidra.dbg.util.PathPredicates;
-import ghidra.dbg.util.PathUtils;
+import ghidra.program.model.address.*;
 import ghidra.test.AbstractGhidraHeadlessIntegrationTest;
 import ghidra.trace.database.ToyDBTraceBuilder;
 import ghidra.trace.model.Lifespan;
 import ghidra.trace.model.target.*;
 import ghidra.trace.model.target.TraceObject.ConflictResolution;
-import ghidra.trace.model.thread.TraceObjectThread;
+import ghidra.trace.model.target.iface.TraceAggregate;
+import ghidra.trace.model.target.path.KeyPath;
+import ghidra.trace.model.target.path.PathFilter;
+import ghidra.trace.model.target.schema.SchemaContext;
+import ghidra.trace.model.target.schema.TraceObjectSchema.SchemaName;
+import ghidra.trace.model.thread.TraceThread;
 import ghidra.util.database.DBAnnotatedObject;
 import ghidra.util.database.DBCachedObjectStore;
 
 public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationTest {
-	public static final String XML_CTX = """
-			<context>
-			    <schema name='Session' elementResync='NEVER' attributeResync='ONCE'>
-			        <attribute name='curTarget' schema='Target' />
-			        <attribute name='Targets' schema='TargetContainer' />
-			    </schema>
-			    <schema name='TargetContainer' canonical='yes' elementResync='NEVER'
-			            attributeResync='ONCE'>
-			        <element schema='Target' />
-			    </schema>
-			    <schema name='Target' elementResync='NEVER' attributeResync='NEVER'>
-			        <interface name='Process' />
-			        <attribute name='self' schema='Target' />
-			        <attribute name='Threads' schema='ThreadContainer' />
-			        <attribute name='Memory' schema='Memory' />
-			    </schema>
-			    <schema name='ThreadContainer' canonical='yes' elementResync='NEVER'
-			            attributeResync='NEVER'>
-			        <element schema='Thread' />
-			    </schema>
-			    <schema name='Thread' elementResync='NEVER' attributeResync='NEVER'>
-			        <interface name='Thread' />
-			        <interface name='Aggregate' />
-			        <attribute name='Registers' schema='RegisterContainer' />
-			    </schema>
-			    <schema name='RegisterContainer' elementResync='NEVER' attributeResync='NEVER'>
-			        <interface name='RegisterContainer' />
-			        <attribute name='User' schema='RegisterGroup' />
-			        <attribute name='Float' schema='RegisterGroup' />
-			    </schema>
-			    <schema name='RegisterGroup' canonical='yes' elementResync='NEVER'
-			            attributeResync='NEVER'>
-			        <element schema='Register' />
-			    </schema>
-			    <schema name='Register' elementResync='NEVER' attributeResync='NEVER'>
-			        <interface name='Register' />
-			    </schema>
-			    <schema name='Memory' canonical='yes' elementResync='NEVER'
-			            attributeResync='NEVER'>
-			        <element schema='Region' />
-			    </schema>
-			    <schema name='Region' elementResync='NEVER' attributeResync='NEVER'>
-			        <interface name='MemoryRegion' />
-			    </schema>
-			</context>
-			""";
 	protected ToyDBTraceBuilder b;
 	protected DBTraceObjectManager manager;
 
-	protected SchemaContext ctx;
+	protected SchemaContext ctx = ToyDBTraceBuilder.CTX_DEFAULT;
 
 	protected TraceObject root;
 	protected TraceObject targetContainer;
@@ -100,32 +57,30 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 	public void setUpObjectManagerTest() throws Exception {
 		b = new ToyDBTraceBuilder("Testing", "Toy:BE:64:default");
 		manager = b.trace.getObjectManager();
-
-		ctx = XmlSchemaContext.deserialize(XML_CTX);
 	}
 
 	protected void populateModel(int targetCount) {
 		try (Transaction tx = b.startTransaction()) {
 			root = manager.createRootObject(ctx.getSchema(new SchemaName("Session"))).getChild();
-			TraceObjectKeyPath pathTargets = TraceObjectKeyPath.of("Targets");
+			KeyPath pathTargets = KeyPath.of("Targets");
 			targetContainer = manager.createObject(pathTargets);
 			root.setAttribute(Lifespan.nowOn(0), "Targets", targetContainer);
-			dumpStore(manager.valueStore);
+			dumpStore(manager.valueTree.getDataStore());
 
 			for (int i = 0; i < targetCount; i++) {
 				Lifespan lifespan = Lifespan.nowOn(i);
 				TraceObject target = manager.createObject(pathTargets.index(i));
 				target.setAttribute(Lifespan.ALL, "self", target);
-				dumpStore(manager.valueStore);
+				dumpStore(manager.valueTree.getDataStore());
 				targetContainer.setElement(lifespan, i, target);
-				dumpStore(manager.valueStore);
+				dumpStore(manager.valueTree.getDataStore());
 				targets.add(target);
 				root.setAttribute(lifespan, "curTarget", target);
-				dumpStore(manager.valueStore);
+				dumpStore(manager.valueTree.getDataStore());
 			}
 
 			root.setValue(Lifespan.ALL, "anAttribute", "A primitive string");
-			dumpStore(manager.valueStore);
+			dumpStore(manager.valueTree.getDataStore());
 		}
 	}
 
@@ -141,7 +96,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 	@Test(expected = IllegalStateException.class)
 	public void testCreateObjectWithoutRootErr() {
 		try (Transaction tx = b.startTransaction()) {
-			manager.createObject(TraceObjectKeyPath.of("Test"));
+			manager.createObject(KeyPath.of("Test"));
 		}
 	}
 
@@ -152,7 +107,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 	@Test(expected = IllegalArgumentException.class)
 	public void testCreateObjectAsRootErrNoSchema() {
 		try (Transaction tx = b.startTransaction()) {
-			manager.createObject(TraceObjectKeyPath.of());
+			manager.createObject(KeyPath.of());
 		}
 	}
 
@@ -164,7 +119,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 	public void testCreateObjectAsRootErrRootExists() {
 		try (Transaction tx = b.startTransaction()) {
 			manager.createRootObject(ctx.getSchema(new SchemaName("Session")));
-			manager.createObject(TraceObjectKeyPath.of());
+			manager.createObject(KeyPath.of());
 		}
 	}
 
@@ -203,32 +158,32 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		TraceObject obj;
 		try (Transaction tx = b.startTransaction()) {
 			manager.createRootObject(ctx.getSchema(new SchemaName("Session")));
-			obj = manager.createObject(TraceObjectKeyPath.of("Targets"));
+			obj = manager.createObject(KeyPath.of("Targets"));
 		}
-		assertEquals(TraceObjectKeyPath.of("Targets"), obj.getCanonicalPath());
+		assertEquals(KeyPath.of("Targets"), obj.getCanonicalPath());
 	}
 
 	@Test
 	public void testGetObjectsByCanonicalPath() {
 		try (Transaction tx = b.startTransaction()) {
 			root = manager.createRootObject(ctx.getSchema(new SchemaName("Session"))).getChild();
-			targetContainer = manager.createObject(TraceObjectKeyPath.of("Targets"));
+			targetContainer = manager.createObject(KeyPath.of("Targets"));
 		}
 
-		assertNull(manager.getObjectByCanonicalPath(TraceObjectKeyPath.of("Nothing")));
-		assertEquals(root, manager.getObjectByCanonicalPath(TraceObjectKeyPath.of()));
+		assertNull(manager.getObjectByCanonicalPath(KeyPath.of("Nothing")));
+		assertEquals(root, manager.getObjectByCanonicalPath(KeyPath.of()));
 		assertEquals(targetContainer,
-			manager.getObjectByCanonicalPath(TraceObjectKeyPath.of("Targets")));
+			manager.getObjectByCanonicalPath(KeyPath.of("Targets")));
 	}
 
 	@Test
 	public void testGetValuesByPathRootOnly() {
-		assertEquals(0, manager.getValuePaths(Lifespan.ALL, PathPredicates.pattern()).count());
+		assertEquals(0, manager.getValuePaths(Lifespan.ALL, PathFilter.pattern()).count());
 
 		try (Transaction tx = b.startTransaction()) {
 			manager.createRootObject(ctx.getSchema(new SchemaName("Session")));
 		}
-		assertEquals(1, manager.getValuePaths(Lifespan.ALL, PathPredicates.pattern()).count());
+		assertEquals(1, manager.getValuePaths(Lifespan.ALL, PathFilter.pattern()).count());
 	}
 
 	@Test
@@ -236,23 +191,23 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		populateModel(2);
 
 		assertEquals(1,
-			manager.getObjectsByPath(Lifespan.at(0), TraceObjectKeyPath.parse("Targets[0]"))
+			manager.getObjectsByPath(Lifespan.at(0), KeyPath.parse("Targets[0]"))
 					.count());
 		assertEquals(0,
-			manager.getObjectsByPath(Lifespan.at(0), TraceObjectKeyPath.parse("Targets[1]"))
+			manager.getObjectsByPath(Lifespan.at(0), KeyPath.parse("Targets[1]"))
 					.count());
 		assertEquals(1,
-			manager.getObjectsByPath(Lifespan.at(1), TraceObjectKeyPath.parse("Targets[1]"))
+			manager.getObjectsByPath(Lifespan.at(1), KeyPath.parse("Targets[1]"))
 					.count());
 		assertEquals(2,
-			manager.getObjectsByPath(Lifespan.ALL, TraceObjectKeyPath.parse("curTarget")).count());
+			manager.getObjectsByPath(Lifespan.ALL, KeyPath.parse("curTarget")).count());
 
 		TraceObject target1 =
-			manager.getObjectsByPath(Lifespan.ALL, TraceObjectKeyPath.parse("Targets[1]"))
+			manager.getObjectsByPath(Lifespan.ALL, KeyPath.parse("Targets[1]"))
 					.findAny()
 					.get();
 		assertEquals(target1,
-			manager.getObjectsByPath(Lifespan.at(1), TraceObjectKeyPath.parse("curTarget"))
+			manager.getObjectsByPath(Lifespan.at(1), KeyPath.parse("curTarget"))
 					.findAny()
 					.get());
 	}
@@ -261,40 +216,44 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 	public void testGetRangeValues() {
 		try (Transaction tx = b.startTransaction()) {
 			root = manager.createRootObject(ctx.getSchema(new SchemaName("Session"))).getChild();
-			targetContainer = manager.createObject(TraceObjectKeyPath.parse("Targets"));
+			targetContainer = manager.createObject(KeyPath.parse("Targets"));
 			root.setAttribute(Lifespan.ALL, "Targets", targetContainer);
 
 			TraceObjectValue rangeVal =
 				root.setValue(Lifespan.nowOn(0), "a", b.range(0x1000, 0x1fff));
 
-			assertTrue(root.getValues().contains(rangeVal));
-			assertFalse(targetContainer.getValues().contains(rangeVal));
+			assertTrue(root.getValues(Lifespan.at(0)).contains(rangeVal));
+			assertFalse(targetContainer.getValues(Lifespan.ALL).contains(rangeVal));
 			assertEquals(rangeVal, root.getValue(0, "a"));
 			assertNull(root.getValue(0, "b"));
 
 			assertEquals(Set.of(rangeVal),
-				root.getSuccessors(Lifespan.ALL, PathPredicates.parse("a"))
+				root.getSuccessors(Lifespan.ALL, PathFilter.parse("a"))
 						.map(p -> p.getLastEntry())
 						.collect(Collectors.toSet()));
 			assertEquals(Set.of(),
-				root.getSuccessors(Lifespan.toNow(-1), PathPredicates.parse("a"))
+				root.getSuccessors(Lifespan.toNow(-1), PathFilter.parse("a"))
 						.map(p -> p.getLastEntry())
 						.collect(Collectors.toSet()));
 			assertEquals(Set.of(),
-				root.getSuccessors(Lifespan.ALL, PathPredicates.parse("b"))
+				root.getSuccessors(Lifespan.ALL, PathFilter.parse("b"))
 						.map(p -> p.getLastEntry())
 						.collect(Collectors.toSet()));
 			assertEquals(Set.of(),
-				targetContainer.getSuccessors(Lifespan.ALL, PathPredicates.parse("a"))
+				targetContainer.getSuccessors(Lifespan.ALL, PathFilter.parse("a"))
 						.map(p -> p.getLastEntry())
 						.collect(Collectors.toSet()));
 
 			assertEquals(Set.of(rangeVal),
 				Set.copyOf(manager.getValuesIntersecting(Lifespan.ALL, b.range(0, -1))));
+			assertEquals(Set.of(rangeVal),
+				Set.copyOf(manager.getValuesIntersecting(Lifespan.ALL, b.range(0, -1), "a")));
 			assertEquals(Set.of(),
 				Set.copyOf(manager.getValuesIntersecting(Lifespan.toNow(-1), b.range(0, -1))));
 			assertEquals(Set.of(),
 				Set.copyOf(manager.getValuesIntersecting(Lifespan.ALL, b.range(0, 0xfff))));
+			assertEquals(Set.of(),
+				Set.copyOf(manager.getValuesIntersecting(Lifespan.ALL, b.range(0, -1), "b")));
 		}
 	}
 
@@ -303,57 +262,57 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		populateModel(3);
 		TraceObject thread;
 		try (Transaction tx = b.startTransaction()) {
-			thread = manager.createObject(TraceObjectKeyPath.parse("Targets[0].Threads[0]"));
+			thread = manager.createObject(KeyPath.parse("Targets[0].Threads[0]"));
 			thread.insert(Lifespan.nowOn(0), ConflictResolution.DENY);
 		}
 
 		assertEquals(Set.of(),
-			manager.queryAllInterface(Lifespan.toNow(-1), TraceObjectThread.class)
+			manager.queryAllInterface(Lifespan.toNow(-1), TraceThread.class)
 					.collect(Collectors.toSet()));
-		assertEquals(Set.of(thread.queryInterface(TraceObjectThread.class)),
-			manager.queryAllInterface(Lifespan.ALL, TraceObjectThread.class)
+		assertEquals(Set.of(thread.queryInterface(TraceThread.class)),
+			manager.queryAllInterface(Lifespan.ALL, TraceThread.class)
 					.collect(Collectors.toSet()));
 	}
 
 	@Test
 	public void testClear() {
 		populateModel(3);
-		assertEquals(5, manager.getAllObjects().size());
+		assertEquals(5, manager.getObjectCount());
 
 		try (Transaction tx = b.startTransaction()) {
 			manager.clear();
 		}
-		assertEquals(0, manager.getAllObjects().size());
+		assertEquals(0, manager.getObjectCount());
 
 		populateModel(3);
-		assertEquals(5, manager.getAllObjects().size());
+		assertEquals(5, manager.getObjectCount());
 	}
 
-	@Test
+	// @Test // Write-behind cache does not implement undo or redo
 	public void testUndoRedo() throws Exception {
 		populateModel(3);
-		assertEquals(5, manager.getAllObjects().size());
+		assertEquals(5, manager.getObjectCount());
 
 		b.trace.undo();
-		assertEquals(0, manager.getAllObjects().size());
+		assertEquals(0, manager.getObjectCount());
 
 		b.trace.redo();
-		assertEquals(5, manager.getAllObjects().size());
+		assertEquals(5, manager.getObjectCount());
 	}
 
-	@Test
+	// @Test // Write-behind cache does not implement abort
 	public void testAbort() throws Exception {
 		try (Transaction tx = b.startTransaction()) {
 			populateModel(3);
-			assertEquals(5, manager.getAllObjects().size());
+			assertEquals(5, manager.getObjectCount());
 
 			tx.abort();
 		}
 
-		assertEquals(0, manager.getAllObjects().size());
+		assertEquals(0, manager.getObjectCount());
 
 		populateModel(3);
-		assertEquals(5, manager.getAllObjects().size());
+		assertEquals(5, manager.getObjectCount());
 	}
 
 	@Test
@@ -368,7 +327,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 	public void testIsRoot() {
 		try (Transaction tx = b.startTransaction()) {
 			root = manager.createRootObject(ctx.getSchema(new SchemaName("Session"))).getChild();
-			targetContainer = manager.createObject(TraceObjectKeyPath.of("Targets"));
+			targetContainer = manager.createObject(KeyPath.of("Targets"));
 		}
 
 		assertTrue(root.isRoot());
@@ -380,7 +339,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		populateModel(3);
 
 		TraceObject object = Unique.assertOne(
-			manager.getObjectsByPath(Lifespan.at(0), TraceObjectKeyPath.parse("curTarget")));
+			manager.getObjectsByPath(Lifespan.at(0), KeyPath.parse("curTarget")));
 
 		List<TraceObjectValPath> paths =
 			object.getAllPaths(Lifespan.at(0)).collect(Collectors.toList());
@@ -391,19 +350,19 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 
 		path = paths.get(0);
 		assertEquals(object, path.getDestination(root));
-		assertEquals(PathUtils.parse("Targets[0]"), path.getKeyList());
+		assertEquals(KeyPath.parse("Targets[0]"), path.getPath());
 
 		path = paths.get(1);
 		assertEquals(object, path.getDestination(root));
-		assertEquals(PathUtils.parse("Targets[0].self"), path.getKeyList());
+		assertEquals(KeyPath.parse("Targets[0].self"), path.getPath());
 
 		path = paths.get(2);
 		assertEquals(object, path.getDestination(root));
-		assertEquals(List.of("curTarget"), path.getKeyList());
+		assertEquals(KeyPath.of("curTarget"), path.getPath());
 
 		path = paths.get(3);
 		assertEquals(object, path.getDestination(root));
-		assertEquals(PathUtils.parse("curTarget.self"), path.getKeyList());
+		assertEquals(KeyPath.parse("curTarget.self"), path.getPath());
 
 		paths = root.getAllPaths(Lifespan.ALL).collect(Collectors.toList());
 		assertEquals(1, paths.size());
@@ -417,11 +376,14 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		try (Transaction tx = b.startTransaction()) {
 			root = manager.createRootObject(ctx.getSchema(new SchemaName("Session"))).getChild();
 
-			thread = manager.createObject(TraceObjectKeyPath.parse("Targets[0].Threads[0]"));
+			thread = manager.createObject(KeyPath.parse("Targets[0].Threads[0]"));
 			thread.insert(Lifespan.nowOn(0), ConflictResolution.DENY);
 		}
 		assertEquals(Set.of(), root.getInterfaces());
-		assertEquals(Set.of(TraceObjectThread.class), thread.getInterfaces());
+		assertEquals(Set.of(
+			TraceAggregate.class,
+			TraceThread.class),
+			thread.getInterfaces());
 	}
 
 	@Test
@@ -430,45 +392,46 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		try (Transaction tx = b.startTransaction()) {
 			root = manager.createRootObject(ctx.getSchema(new SchemaName("Session"))).getChild();
 
-			thread = manager.createObject(TraceObjectKeyPath.parse("Targets[0].Threads[0]"));
+			thread = manager.createObject(KeyPath.parse("Targets[0].Threads[0]"));
 			thread.insert(Lifespan.nowOn(0), ConflictResolution.DENY);
 		}
-		assertNull(root.queryInterface(TraceObjectThread.class));
-		TraceObjectThread threadIf = thread.queryInterface(TraceObjectThread.class);
+		assertNull(root.queryInterface(TraceThread.class));
+		TraceThread threadIf = thread.queryInterface(TraceThread.class);
 		assertNotNull(threadIf);
-		assertSame(threadIf, thread.queryInterface(TraceObjectThread.class));
+		assertSame(threadIf, thread.queryInterface(TraceThread.class));
 	}
 
 	@Test
 	public void testGetParents() {
 		populateModel(3);
 
-		assertEquals(1, root.getParents().size());
-		assertEquals(root, Unique.assertOne(targetContainer.getParents()).getParent());
-		assertEquals(3, targets.get(0).getParents().size()); // curTarget, targetContainer, self
+		assertEquals(1, root.getParents(Lifespan.ALL).size());
+		assertEquals(root, Unique.assertOne(targetContainer.getParents(Lifespan.ALL)).getParent());
+		assertEquals(3, targets.get(0).getParents(Lifespan.ALL).size());
+		// curTarget, targetContainer, self
 	}
 
 	@Test
 	public void testGetValues() {
 		populateModel(3);
 
-		assertEquals(3, targetContainer.getValues().size());
+		assertEquals(3, targetContainer.getValues(Lifespan.ALL).size());
 	}
 
 	@Test
 	public void testGetElements() {
 		populateModel(3);
 
-		assertEquals(0, root.getElements().size());
-		assertEquals(3, targetContainer.getElements().size());
+		assertEquals(0, root.getElements(Lifespan.ALL).size());
+		assertEquals(3, targetContainer.getElements(Lifespan.ALL).size());
 	}
 
 	@Test
 	public void testGetAttributes() {
 		populateModel(3);
 
-		assertEquals(5, root.getAttributes().size()); // Targets, curTarget(x3), string
-		assertEquals(0, targetContainer.getAttributes().size());
+		assertEquals(5, root.getAttributes(Lifespan.ALL).size()); // Targets, curTarget(x3), string
+		assertEquals(0, targetContainer.getAttributes(Lifespan.ALL).size());
 	}
 
 	@Test
@@ -507,30 +470,30 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 	public void testGetSuccessors() {
 		populateModel(3);
 
-		assertEquals(1, root.getSuccessors(Lifespan.ALL, PathPredicates.parse("")).count());
+		assertEquals(1, root.getSuccessors(Lifespan.ALL, PathFilter.parse("")).count());
 
-		assertEquals(1, root.getSuccessors(Lifespan.ALL, PathPredicates.parse("Targets")).count());
+		assertEquals(1, root.getSuccessors(Lifespan.ALL, PathFilter.parse("Targets")).count());
 
 		assertEquals(1,
-			root.getSuccessors(Lifespan.at(0), PathPredicates.parse("Targets[]")).count());
+			root.getSuccessors(Lifespan.at(0), PathFilter.parse("Targets[]")).count());
 		assertEquals(1,
-			targetContainer.getSuccessors(Lifespan.at(0), PathPredicates.parse("[]")).count());
+			targetContainer.getSuccessors(Lifespan.at(0), PathFilter.parse("[]")).count());
 		assertEquals(3,
-			targetContainer.getSuccessors(Lifespan.ALL, PathPredicates.parse("[]")).count());
+			targetContainer.getSuccessors(Lifespan.ALL, PathFilter.parse("[]")).count());
 
 		assertEquals(3,
-			root.getSuccessors(Lifespan.ALL, PathPredicates.parse("curTarget")).count());
+			root.getSuccessors(Lifespan.ALL, PathFilter.parse("curTarget")).count());
 		assertEquals(2,
-			root.getSuccessors(Lifespan.span(0, 1), PathPredicates.parse("curTarget")).count());
+			root.getSuccessors(Lifespan.span(0, 1), PathFilter.parse("curTarget")).count());
 		assertEquals(1,
-			root.getSuccessors(Lifespan.at(1), PathPredicates.parse("curTarget")).count());
+			root.getSuccessors(Lifespan.at(1), PathFilter.parse("curTarget")).count());
 		assertEquals(0,
-			root.getSuccessors(Lifespan.toNow(-1), PathPredicates.parse("curTarget")).count());
+			root.getSuccessors(Lifespan.toNow(-1), PathFilter.parse("curTarget")).count());
 
 		assertEquals(1,
-			root.getSuccessors(Lifespan.ALL, PathPredicates.parse("anAttribute")).count());
+			root.getSuccessors(Lifespan.ALL, PathFilter.parse("anAttribute")).count());
 		assertEquals(0,
-			root.getSuccessors(Lifespan.ALL, PathPredicates.parse("anAttribute.nope")).count());
+			root.getSuccessors(Lifespan.ALL, PathFilter.parse("anAttribute.nope")).count());
 	}
 
 	@Test
@@ -538,24 +501,31 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		populateModel(3);
 
 		assertEquals(List.of(root),
-			root.getOrderedSuccessors(Lifespan.ALL, TraceObjectKeyPath.parse(""), true)
+			root.getOrderedSuccessors(Lifespan.ALL, KeyPath.parse(""), true)
 					.map(p -> p.getDestination(root))
 					.collect(Collectors.toList()));
 		assertEquals(List.of(root),
-			root.getOrderedSuccessors(Lifespan.ALL, TraceObjectKeyPath.parse(""), false)
+			root.getOrderedSuccessors(Lifespan.ALL, KeyPath.parse(""), false)
 					.map(p -> p.getDestination(root))
 					.collect(Collectors.toList()));
 
 		assertEquals(List.of(targets.get(0), targets.get(1), targets.get(2)),
-			root.getOrderedSuccessors(Lifespan.ALL, TraceObjectKeyPath.parse("curTarget"), true)
+			root.getOrderedSuccessors(Lifespan.ALL, KeyPath.parse("curTarget"), true)
 					.map(p -> p.getDestination(root))
 					.collect(Collectors.toList()));
 		assertEquals(List.of(targets.get(2), targets.get(1), targets.get(0)),
-			root.getOrderedSuccessors(Lifespan.ALL, TraceObjectKeyPath.parse("curTarget"), false)
+			root.getOrderedSuccessors(Lifespan.ALL, KeyPath.parse("curTarget"), false)
 					.map(p -> p.getDestination(root))
 					.collect(Collectors.toList()));
 	}
 
+	@Test
+	public void testGetCanonicalSuccessors() {
+		populateModel(3);
+		assertEquals(3, root.getCanonicalSuccessors(PathFilter.parse("Targets[]")).count());
+		assertEquals(0, root.getCanonicalSuccessors(PathFilter.parse("anAttribute")).count());
+	}
+
 	@Test
 	public void testSetValue_TruncatesOrDeletes() {
 		try (Transaction tx = b.startTransaction()) {
@@ -609,7 +579,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 
 			assertEquals(valA, root.setValue(Lifespan.span(-10, -1), "a", 1));
 			assertEquals(Lifespan.span(-10, 9), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -623,7 +593,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 			assertEquals(valA,
 				root.setValue(Lifespan.span(-10, -1), "a", b.range(0x1000, 0x1fff)));
 			assertEquals(Lifespan.span(-10, 9), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -635,7 +605,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 
 			assertEquals(valA, root.setValue(Lifespan.span(10, 19), "a", 1));
 			assertEquals(Lifespan.span(0, 19), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -647,7 +617,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 
 			assertEquals(valA, root.setValue(Lifespan.span(-5, 4), "a", 1));
 			assertEquals(Lifespan.span(-5, 9), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -659,7 +629,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 
 			assertEquals(valA, root.setValue(Lifespan.span(5, 14), "a", 1));
 			assertEquals(Lifespan.span(0, 14), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -671,7 +641,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 
 			assertEquals(valA, root.setValue(Lifespan.span(0, 9), "a", 1));
 			assertEquals(Lifespan.span(0, 9), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -683,11 +653,11 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 
 			assertEquals(valA, root.setValue(Lifespan.at(5), "a", 1));
 			assertEquals(Lifespan.span(0, 9), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 
 			assertEquals(valA, root.setValue(Lifespan.span(-5, 14), "a", 1));
 			assertEquals(Lifespan.span(-5, 14), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -699,11 +669,11 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 
 			assertEquals(valA, root.setValue(Lifespan.span(0, 5), "a", 1));
 			assertEquals(Lifespan.span(0, 9), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 
 			assertEquals(valA, root.setValue(Lifespan.span(0, 14), "a", 1));
 			assertEquals(Lifespan.span(0, 14), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -715,11 +685,11 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 
 			assertEquals(valA, root.setValue(Lifespan.span(5, 9), "a", 1));
 			assertEquals(Lifespan.span(0, 9), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 
 			assertEquals(valA, root.setValue(Lifespan.span(-5, 9), "a", 1));
 			assertEquals(Lifespan.span(-5, 9), valA.getLifespan());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -730,12 +700,12 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 			TraceObjectValue valA = root.setValue(Lifespan.span(0, 9), "a", 1);
 			TraceObjectValue valB = root.setValue(Lifespan.span(20, 29), "a", 1);
 			assertNotSame(valA, valB);
-			assertEquals(2, root.getValues().size());
+			assertEquals(2, root.getValues(Lifespan.ALL).size());
 
 			assertEquals(valA, root.setValue(Lifespan.span(10, 19), "a", 1));
 			assertEquals(Lifespan.span(0, 29), valA.getLifespan());
 			assertTrue(valB.isDeleted());
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -824,13 +794,13 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		try (Transaction tx = b.startTransaction()) {
 			root = manager.createRootObject(ctx.getSchema(new SchemaName("Session"))).getChild();
 			assertNull(root.setValue(Lifespan.span(0, 9), "a", null));
-			assertEquals(0, root.getValues().size());
+			assertEquals(0, root.getValues(Lifespan.ALL).size());
 
 			assertNotNull(root.setValue(Lifespan.span(0, 9), "a", 1));
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 
 			assertNull(root.setValue(Lifespan.at(5), "a", null));
-			assertEquals(2, root.getValues().size());
+			assertEquals(2, root.getValues(Lifespan.ALL).size());
 
 			assertEquals(List.of(Lifespan.span(0, 4), Lifespan.span(6, 9)),
 				root.getOrderedValues(Lifespan.ALL, "a", true)
@@ -844,10 +814,10 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		try (Transaction tx = b.startTransaction()) {
 			root = manager.createRootObject(ctx.getSchema(new SchemaName("Session"))).getChild();
 			assertNotNull(root.setValue(Lifespan.span(0, 9), "a", 1));
-			assertEquals(1, root.getValues().size());
+			assertEquals(1, root.getValues(Lifespan.ALL).size());
 
 			assertNull(root.setValue(Lifespan.span(0, 9), "a", null));
-			assertEquals(0, root.getValues().size());
+			assertEquals(0, root.getValues(Lifespan.ALL).size());
 		}
 	}
 
@@ -878,9 +848,9 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		// Delete a leaf
 		TraceObject t1 = targets.get(1);
 		assertFalse(t1.isDeleted());
-		assertEquals(3, targetContainer.getValues().size());
+		assertEquals(3, targetContainer.getValues(Lifespan.ALL).size());
 		assertEquals(t1, Unique.assertOne(
-			manager.getObjectsByPath(Lifespan.ALL, TraceObjectKeyPath.parse("Targets[1]"))));
+			manager.getObjectsByPath(Lifespan.ALL, KeyPath.parse("Targets[1]"))));
 		assertEquals(t1, t1.getAttribute(1, "self").getValue());
 		assertEquals(t1, root.getValue(1, "curTarget").getValue());
 
@@ -889,33 +859,35 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 		}
 
 		assertTrue(t1.isDeleted());
-		assertTrue(t1.getParents().isEmpty());
-		assertEquals(2, targetContainer.getValues().size());
+		assertTrue(t1.getParents(Lifespan.ALL).isEmpty());
+		assertEquals(2, targetContainer.getValues(Lifespan.ALL).size());
 		assertEquals(0,
-			manager.getObjectsByPath(Lifespan.ALL, TraceObjectKeyPath.parse("Targets[1]")).count());
+			manager.getObjectsByPath(Lifespan.ALL, KeyPath.parse("Targets[1]")).count());
 		assertNull(t1.getAttribute(2, "self"));
 		assertNull(root.getValue(1, "curTarget"));
 
 		// Delete a branch (leaves stay, but detached)
 		TraceObject t0 = targets.get(0);
 		assertEquals(2,
-			manager.getObjectsByPath(Lifespan.ALL, TraceObjectKeyPath.parse("Targets[]")).count());
-		assertTrue(t0.getParents().stream().anyMatch(v -> v.getParent() == targetContainer));
-		assertEquals(2, targetContainer.getValues().size());
+			manager.getObjectsByPath(Lifespan.ALL, KeyPath.parse("Targets[]")).count());
+		assertTrue(
+			t0.getParents(Lifespan.ALL).stream().anyMatch(v -> v.getParent() == targetContainer));
+		assertEquals(2, targetContainer.getValues(Lifespan.ALL).size());
 
 		b.trace.undo();
 		b.trace.redo();
 
-		assertEquals(2, targetContainer.getValues().size());
+		assertEquals(2, targetContainer.getValues(Lifespan.ALL).size());
 
 		try (Transaction tx = b.startTransaction()) {
 			targetContainer.delete();
 		}
 
 		assertEquals(0,
-			manager.getObjectsByPath(Lifespan.ALL, TraceObjectKeyPath.parse("Targets[]")).count());
+			manager.getObjectsByPath(Lifespan.ALL, KeyPath.parse("Targets[]")).count());
 		assertFalse(t0.isDeleted());
-		assertFalse(t0.getParents().stream().anyMatch(v -> v.getParent() == targetContainer));
+		assertFalse(
+			t0.getParents(Lifespan.ALL).stream().anyMatch(v -> v.getParent() == targetContainer));
 		// A little odd, but allows branch to be replaced and successors restored later
 		assertEquals(t0, root.getValue(0, "curTarget").getValue());
 	}
@@ -997,7 +969,7 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 			TraceObjectValue primVal = root.setValue(Lifespan.ALL, "primitive", "A string");
 			assertFalse(primVal.isCanonical());
 
-			TraceObject child = manager.createObject(TraceObjectKeyPath.parse("child"));
+			TraceObject child = manager.createObject(KeyPath.parse("child"));
 
 			TraceObjectValue objVal = root.setValue(Lifespan.ALL, "child", child);
 			assertTrue(objVal.isCanonical());
@@ -1063,4 +1035,131 @@ public class DBTraceObjectManagerTest extends AbstractGhidraHeadlessIntegrationT
 			assertFalse(split.isDeleted()); // Other values not affected
 		}
 	}
+
+	@Test
+	public void testAttributeDefaultVisibility() {
+		try (Transaction tx = b.startTransaction()) {
+			TraceObjectValue rootVal =
+				manager.createRootObject(ctx.getSchema(new SchemaName("Session")));
+			root = rootVal.getChild();
+
+			TraceObject object = manager.createObject(KeyPath.parse("OutsideSchema"));
+			object.insert(Lifespan.ALL, ConflictResolution.DENY);
+			assertFalse(object.getCanonicalParent(0).isHidden());
+
+			TraceObject elemOutside =
+				manager.createObject(KeyPath.parse("OutsideSchema[0]"));
+			elemOutside.insert(Lifespan.ALL, ConflictResolution.DENY);
+			assertFalse(elemOutside.getCanonicalParent(0).isHidden());
+
+			TraceObject attrOutside =
+				manager.createObject(KeyPath.parse("OutsideSchema.Attr"));
+			attrOutside.insert(Lifespan.ALL, ConflictResolution.DENY);
+			assertFalse(attrOutside.getCanonicalParent(0).isHidden());
+
+			// TODO: This underscore convention is deprecated, but still in use
+			TraceObject hiddenOutside =
+				manager.createObject(KeyPath.parse("OutsideSchema._Attr"));
+			hiddenOutside.insert(Lifespan.ALL, ConflictResolution.DENY);
+			assertTrue(hiddenOutside.getCanonicalParent(0).isHidden());
+		}
+	}
+
+	protected String randomIdentifier(Random random, int length) {
+		StringBuilder sb = new StringBuilder(length);
+		while (sb.length() < length) {
+			char c = (char) random.nextInt();
+			boolean isValid = sb.isEmpty()
+					? Character.isJavaIdentifierStart(c)
+					: Character.isJavaIdentifierPart(c);
+			if (isValid) {
+				sb.append(c);
+				continue;
+			}
+		}
+		return sb.toString();
+	}
+
+	protected Address randomAddress(Random random) {
+		List<AddressSpace> spaces = Stream.of(b.trace.getBaseAddressFactory().getAllAddressSpaces())
+				.filter(s -> s.isMemorySpace() || s.isRegisterSpace())
+				.toList();
+		AddressSpace space = spaces.get(random.nextInt(spaces.size()));
+		while (true) {
+			BigInteger offset = new BigInteger(space.getSize(), random);
+			try {
+				return space.getAddress(offset.longValue());
+			}
+			catch (AddressOutOfBoundsException e) {
+				continue;
+			}
+		}
+	}
+
+	protected Lifespan randomLifespan(Random random) {
+		boolean isNowOn = random.nextInt(4) < 3;
+		if (isNowOn) {
+			return Lifespan.nowOn(random.nextLong(10000));
+		}
+		int length = random.nextInt(10000);
+		long start = random.nextLong(10000);
+		return Lifespan.span(start, start + length);
+	}
+
+	protected void assertSameResult(Collection<TraceObjectValue> values, Lifespan span,
+			AddressRange range) {
+		List<TraceObjectValue> expected = values.stream()
+				.filter(v -> v.getLifespan().intersects(span) && range.contains(v.castValue()))
+				.toList();
+		List<TraceObjectValue> actual =
+			List.copyOf(b.trace.getObjectManager().getValuesIntersecting(span, range));
+		assertEquals(expected, actual);
+	}
+
+	@Test
+	public void testManyAddressValuesAcrossSpaces() {
+		Random random = new Random();
+		List<TraceObjectValue> values = new ArrayList<>();
+		try (Transaction tx = b.startTransaction()) {
+			TraceObjectValue rootVal =
+				manager.createRootObject(ctx.getSchema(new SchemaName("Session")));
+			root = rootVal.getChild();
+
+			for (int i = 0; i < 1000; i++) {
+				String key = randomIdentifier(random, 6);
+				Address addr = randomAddress(random);
+				Lifespan lifespan = randomLifespan(random);
+
+				values.add(root.setAttribute(lifespan, key, addr));
+			}
+		}
+
+		b.trace.getObjectManager().getValuesIntersecting(Lifespan.ALL, b.range(0, -1));
+	}
+
+	@Test
+	public void testAttributeAliasing() {
+		TraceObject regionText;
+		try (Transaction tx = b.startTransaction()) {
+			TraceObjectValue rootVal =
+				manager.createRootObject(ctx.getSchema(new SchemaName("Session")));
+			root = rootVal.getChild();
+
+			regionText =
+				manager.createObject(KeyPath.parse("Targets[0].Memory[bin:.text]"));
+			regionText.insert(Lifespan.nowOn(0), ConflictResolution.DENY);
+			regionText.setAttribute(Lifespan.nowOn(0), "_range", b.range(0x00400000, 0x00401000));
+			regionText.setAttribute(Lifespan.nowOn(0), "Range", b.range(0x00400000, 0x00402000));
+		}
+
+		assertEquals(ctx.getSchema(new SchemaName("Region")), regionText.getSchema());
+		assertEquals(Set.of(
+			regionText.getAttribute(0, "Range")),
+			Set.copyOf(regionText.getAttributes(Lifespan.ALL)));
+		assertEquals(b.range(0x00400000, 0x00402000),
+			regionText.getAttribute(0, "_range").getValue());
+		assertEquals(b.range(0x00400000, 0x00402000),
+			regionText.getAttribute(0, "Range").getValue());
+		assertEquals("Range", regionText.getAttribute(0, "_range").getEntryKey());
+	}
 }
