@@ -25,6 +25,7 @@ import ghidra.app.plugin.core.datamgr.archive.DefaultDataTypeArchiveService;
 import ghidra.app.services.DataTypeManagerService;
 import ghidra.program.model.data.*;
 import ghidra.util.HelpLocation;
+import ghidra.util.task.TaskMonitor;
 
 // FIXME!! TESTING
 public class DefaultDataTypeManagerService extends DefaultDataTypeArchiveService
@@ -64,6 +65,26 @@ public class DefaultDataTypeManagerService extends DefaultDataTypeArchiveService
 		throw new UnsupportedOperationException();
 	}
 
+	@Override
+	public List<DataType> getDataTypesByPath(DataTypePath path) {
+		throw new UnsupportedOperationException();
+	}
+
+	@Override
+	public DataType getProgramDataTypeByPath(DataTypePath path) {
+		throw new UnsupportedOperationException();
+	}
+
+	@Override
+	public DataType promptForDataType(String filterText) {
+		throw new UnsupportedOperationException();
+	}
+
+	@Override
+	public List<DataType> findDataTypes(String name, TaskMonitor monitor) {
+		throw new UnsupportedOperationException();
+	}
+
 	@Override
 	public DataType getDataType(TreePath selectedTreeNode) {
 		if (selectedTreeNode == null) {
@@ -72,6 +93,11 @@ public class DefaultDataTypeManagerService extends DefaultDataTypeArchiveService
 		throw new UnsupportedOperationException();
 	}
 
+	@Override
+	public CategoryPath getCategoryPath(TreePath selectedPath) {
+		throw new UnsupportedOperationException();
+	}
+
 	@Override
 	public List<DataType> getFavorites() {
 		throw new UnsupportedOperationException();
@@ -90,6 +116,11 @@ public class DefaultDataTypeManagerService extends DefaultDataTypeArchiveService
 		return dataTypes;
 	}
 
+	@Override
+	public List<CategoryPath> getSortedCategoryPathList() {
+		throw new UnsupportedOperationException();
+	}
+
 	@Override
 	public void removeDataTypeManagerChangeListener(DataTypeManagerChangeListener listener) {
 		throw new UnsupportedOperationException();
