@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -62,9 +62,8 @@ public class MingwRelocationAnalyzer extends AbstractAnalyzer {
 		if (!program.hasExclusiveAccess()) {
 			// Exclusive access required since relocation table lacks merge support
 			if (!alreadyProcessed(program)) {
-				Msg.error(this,
-					NAME + " analyzer disabled; requires exclusive access to " +
-						program.getDomainFile());
+				Msg.error(this, NAME + " analyzer disabled; requires exclusive access to " +
+					program.getDomainFile());
 			}
 			return false;
 		}
@@ -226,11 +225,9 @@ class MinGWPseudoRelocationHandler {
 	static boolean isSupportedProgram(Program program) {
 		Language language = program.getLanguage();
 		int size = language.getLanguageDescription().getSize();
-		return "x86".equals(language.getProcessor().toString()) &&
-			(size == 32 || size == 64) &&
+		return "x86".equals(language.getProcessor().toString()) && (size == 32 || size == 64) &&
 			"windows".equals(program.getCompilerSpec().getCompilerSpecID().toString()) &&
-			CompilerEnum.GCC.label.equals(program.getCompiler()) &&
-			getRDataBlock(program) != null;
+			CompilerEnum.GCC.label.equals(program.getCompiler()) && getRDataBlock(program) != null;
 	}
 
 	private static MemoryBlock getRDataBlock(Program program) {
@@ -252,7 +249,6 @@ class MinGWPseudoRelocationHandler {
 		}
 	}
 
-
 	boolean processRelocations(MessageLog log, TaskMonitor monitor) throws CancelledException {
 
 		Address pdwListBeginAddr = relocList.getListStartAddress();
@@ -297,8 +293,8 @@ class MinGWPseudoRelocationHandler {
 		boolean success;
 		switch (version) {
 			case RP_VERSION_V1:
-				success = relocateV1(pdwListBeginAddr, (int) (size / OLD_STYLE_ENTRY_SIZE), log,
-					monitor);
+				success =
+					relocateV1(pdwListBeginAddr, (int) (size / OLD_STYLE_ENTRY_SIZE), log, monitor);
 				break;
 			case RP_VERSION_V2:
 				success = relocateV2(pdwListBeginAddr, (int) (size / NEW_STYLE_ENTRY_HEADER_SIZE),
@@ -369,8 +365,7 @@ class MinGWPseudoRelocationHandler {
 				return existingEntry;
 			}
 
-			Reference ref =
-				program.getReferenceManager().getPrimaryReferenceFrom(iatEntryAddr, 0);
+			Reference ref = program.getReferenceManager().getPrimaryReferenceFrom(iatEntryAddr, 0);
 			if (!ref.isExternalReference()) {
 				return null;
 			}
@@ -380,8 +375,7 @@ class MinGWPseudoRelocationHandler {
 				return null;
 			}
 
-			ExternalLocation extLoc =
-				program.getExternalManager().getExternalLocation(extSym);
+			ExternalLocation extLoc = program.getExternalManager().getExternalLocation(extSym);
 			if (extLoc == null) {
 				return null;
 			}
@@ -410,7 +404,7 @@ class MinGWPseudoRelocationHandler {
 				else {
 					// TODO: Not sure how to preserve relationship to external symbol 
 					// which refers to Library
-					listing.setComment(nextExtAddr, CodeUnit.PLATE_COMMENT,
+					listing.setComment(nextExtAddr, CommentType.PLATE,
 						"External Location: " + extSym.getName(true));
 					String name = extLoc.getOriginalImportedName();
 					boolean demangle = true;
@@ -583,12 +577,12 @@ class MinGWPseudoRelocationHandler {
 				}
 
 				if (addend != 0) {
-					ElfRelocationHandler.warnExternalOffsetRelocation(program,
-						targetAddr, pointerValue, symbolName, addend, null);
+					ElfRelocationHandler.warnExternalOffsetRelocation(program, targetAddr,
+						pointerValue, symbolName, addend, null);
 					if (!memory.getBlock(targetAddr).isExecute()) {
 						// assume pointer if not in execute block
-						ElfRelocationHandler.applyComponentOffsetPointer(program,
-							targetAddr, addend);
+						ElfRelocationHandler.applyComponentOffsetPointer(program, targetAddr,
+							addend);
 					}
 				}
 			}
@@ -624,8 +618,7 @@ class MinGWPseudoRelocationHandler {
 				ClearDataMode.CLEAR_ALL_CONFLICT_DATA);
 		}
 		catch (CodeUnitInsertionException e) {
-			log.appendMsg(
-				"Failed to markup Mingw pseudo-relocation List at: " + pdwListBeginAddr);
+			log.appendMsg("Failed to markup Mingw pseudo-relocation List at: " + pdwListBeginAddr);
 		}
 		return true;
 	}
@@ -640,8 +633,8 @@ class MinGWPseudoRelocationHandler {
 		relocHeaderStruct.add(DWordDataType.dataType, "version", null);
 
 		try {
-			DataUtilities.createData(program, relocHeaderAddr, relocHeaderStruct, -1,
-				false, ClearDataMode.CLEAR_ALL_CONFLICT_DATA);
+			DataUtilities.createData(program, relocHeaderAddr, relocHeaderStruct, -1, false,
+				ClearDataMode.CLEAR_ALL_CONFLICT_DATA);
 		}
 		catch (CodeUnitInsertionException e) {
 			log.appendMsg(
