@@ -57,6 +57,7 @@ public class BatchImportDialog extends DialogComponentProvider {
 
 	private static final String PREF_STRIPCONTAINER = "BATCHIMPORT.STRIPCONTAINER";
 	private static final String PREF_STRIPLEADING = "BATCHIMPORT.STRIPLEADING";
+	private static final String PREF_MIRRORFS = "BATCHIMPORT.MIRRORFS";
 	private static final String LAST_IMPORT_DIR = "LastBatchImportDir";
 
 	/**
@@ -65,7 +66,7 @@ public class BatchImportDialog extends DialogComponentProvider {
 	 * <p>
 	 * The dialog will chain to the {@link ImportBatchTask} when the user clicks the
 	 * OK button.
-	 * <p>
+	 * 
 	 * @param tool {@link PluginTool} that will be the parent of the dialog
 	 * @param batchInfo optional {@link BatchInfo} instance with already discovered applications, or null.
 	 * @param initialFiles optional {@link List} of {@link FSRL files} to add to the batch import dialog, or null.
@@ -92,8 +93,13 @@ public class BatchImportDialog extends DialogComponentProvider {
 	private ProgramManager programManager;
 	private boolean stripLeading = getBooleanPref(PREF_STRIPLEADING, true);
 	private boolean stripContainer = getBooleanPref(PREF_STRIPCONTAINER, false);
+	private boolean mirrorFs = getBooleanPref(PREF_MIRRORFS, false);
 	private boolean openAfterImporting = false;
 
+	private GCheckBox stripLeadingCb;
+	private GCheckBox stripContainerCb;
+	private GCheckBox mirrorFsCb;
+
 	private BatchImportTableModel tableModel;
 	private GTable table;
 	private JButton removeSourceButton;
@@ -130,7 +136,7 @@ public class BatchImportDialog extends DialogComponentProvider {
 
 		};
 		table = new GTable(tableModel);
-
+		table.getAccessibleContext().setAccessibleName("Batch Content");
 		table.addMouseListener(new MouseAdapter() {
 			@Override
 			public void mouseClicked(MouseEvent e) {
@@ -178,11 +184,13 @@ public class BatchImportDialog extends DialogComponentProvider {
 		JPanel sourceListPanel = new JPanel();
 		sourceListPanel.setLayout(new BorderLayout());
 		sourceListPanel.setBorder(createTitledBorder("Import Sources", false));
+		sourceListPanel.getAccessibleContext().setAccessibleName("Source List");
 
 		sourceListModel = new SourcesListModel();
 
 		JList<String> sourceList = new JList<>(sourceListModel);
 		sourceList.setName("batch.import.source.list");
+		sourceList.getAccessibleContext().setAccessibleName("Batch Import Source List");
 		sourceList.addListSelectionListener(e -> {
 			if (!e.getValueIsAdjusting()) {
 				boolean hasSelection = sourceList.getSelectedIndices().length > 0;
@@ -191,8 +199,10 @@ public class BatchImportDialog extends DialogComponentProvider {
 		});
 		JScrollPane sourceListScrollPane = new JScrollPane(sourceList);
 		sourceListPanel.add(sourceListScrollPane, BorderLayout.CENTER);
+		sourceListScrollPane.getAccessibleContext().setAccessibleName("Source List Scroll");
 
 		JPanel sourceOptionsPanel = new JPanel();
+		sourceOptionsPanel.getAccessibleContext().setAccessibleName("Source Options");
 
 		// some padding before the files table
 		sourceOptionsPanel.setBorder(BorderFactory.createEmptyBorder(0, 0, 10, 0));
@@ -231,10 +241,13 @@ public class BatchImportDialog extends DialogComponentProvider {
 
 		JPanel sourceListButtonsPanel = new JPanel();
 		sourceListButtonsPanel.setLayout(new BorderLayout());
+		sourceListButtonsPanel.getAccessibleContext().setAccessibleName("Source List Buttons");
 
 		JButton addSourceButton = new JButton("Add");
+		addSourceButton.getAccessibleContext().setAccessibleName("Add Source");
 		this.removeSourceButton = new JButton("Remove");
 		removeSourceButton.setEnabled(false);
+		removeSourceButton.getAccessibleContext().setAccessibleName("Remove");
 
 		addSourceButton.addActionListener(e -> {
 			addSources();
@@ -282,11 +295,13 @@ public class BatchImportDialog extends DialogComponentProvider {
 		});
 
 		JPanel outputOptionsPanel = buildOutputOptionsPanel();
+		outputOptionsPanel.getAccessibleContext().setAccessibleName("Output Options");
 
 		Box box = Box.createVerticalBox();
 		box.add(sourceListPanel);
 		box.add(filesPanel);
 		box.add(outputOptionsPanel);
+		box.getAccessibleContext().setAccessibleName("Batch Import");
 
 		addOKButton();
 		addCancelButton();
@@ -304,24 +319,36 @@ public class BatchImportDialog extends DialogComponentProvider {
 
 		JPanel outputChoicesPanel = new JPanel();
 		outputChoicesPanel.setLayout(new BoxLayout(outputChoicesPanel, BoxLayout.LINE_AXIS));
+		outputChoicesPanel.getAccessibleContext().setAccessibleName("Output Choices");
 
-		GCheckBox stripLeadingCb = new GCheckBox("Strip leading path", stripLeading);
+		stripLeadingCb = new GCheckBox("Strip leading path", stripLeading);
 		stripLeadingCb.addChangeListener(e -> setStripLeading(stripLeadingCb.isSelected()));
 		stripLeadingCb.setToolTipText("The destination folder for imported files will not " +
 			"include the source file's leading path");
+		stripLeadingCb.getAccessibleContext().setAccessibleName("Strip Leading Path");
 
-		GCheckBox stripContainerCb = new GCheckBox("Strip container paths", stripContainer);
+		stripContainerCb = new GCheckBox("Strip container paths", stripContainer);
 		stripContainerCb.addChangeListener(e -> setStripContainer(stripContainerCb.isSelected()));
 		stripContainerCb.setToolTipText(
 			"The destination folder for imported files will not include any source path names");
+		stripContainerCb.getAccessibleContext().setAccessibleName("Strip Container Paths");
+
+		mirrorFsCb = new GCheckBox("Mirror Filesystem", mirrorFs);
+		mirrorFsCb.addChangeListener(e -> setMirrorFs(mirrorFsCb.isSelected()));
+		mirrorFsCb.setToolTipText(
+			"The imported files' project paths will mirror the filesystem rooted at the desination folder");
+		mirrorFsCb.getAccessibleContext().setAccessibleName("Mirror Filesystem");
+		setMirrorFs(mirrorFs); // needed to possibly disable other checkboxes
 
 		GCheckBox openAfterImportCb = new GCheckBox("Open after import", openAfterImporting);
-		openAfterImportCb.addChangeListener(
-			e -> setOpenAfterImporting(openAfterImportCb.isSelected()));
+		openAfterImportCb
+				.addChangeListener(e -> setOpenAfterImporting(openAfterImportCb.isSelected()));
 		openAfterImportCb.setToolTipText("Open imported binaries in Code Browser");
+		openAfterImportCb.getAccessibleContext().setAccessibleName("Open After Import");
 
 		outputChoicesPanel.add(stripLeadingCb);
 		outputChoicesPanel.add(stripContainerCb);
+		outputChoicesPanel.add(mirrorFsCb);
 		if (programManager != null) {
 			outputChoicesPanel.add(openAfterImportCb);
 		}
@@ -341,6 +368,7 @@ public class BatchImportDialog extends DialogComponentProvider {
 		outputOptionsPanel.setBorder(createTitledBorder("Import Options", true));
 		outputOptionsPanel.add(outputChoicesPanel, BorderLayout.NORTH);
 		outputOptionsPanel.add(destPanel, BorderLayout.SOUTH);
+		outputOptionsPanel.getAccessibleContext().setAccessibleName("Output Options");
 		return outputOptionsPanel;
 	}
 
@@ -450,7 +478,7 @@ public class BatchImportDialog extends DialogComponentProvider {
 	protected void okCallback() {
 		new TaskLauncher(
 			new ImportBatchTask(batchInfo, destinationFolder,
-				openAfterImporting ? programManager : null, stripLeading, stripContainer),
+				openAfterImporting ? programManager : null, stripLeading, stripContainer, mirrorFs),
 			getComponent());
 		close();
 	}
@@ -602,6 +630,13 @@ public class BatchImportDialog extends DialogComponentProvider {
 		setBooleanPref(PREF_STRIPCONTAINER, stripContainer);
 	}
 
+	private void setMirrorFs(boolean mirrorFs) {
+		this.mirrorFs = mirrorFs;
+		setBooleanPref(PREF_MIRRORFS, mirrorFs);
+		stripContainerCb.setEnabled(!mirrorFs);
+		stripContainerCb.setSelected(mirrorFs ? false : stripContainer);
+	}
+
 	private void setMaxDepth(int newMaxDepth) {
 		if (newMaxDepth == batchInfo.getMaxDepth()) {
 			return;
