@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -32,9 +32,10 @@ import docking.widgets.fieldpanel.*;
 import docking.widgets.fieldpanel.field.Field;
 import docking.widgets.fieldpanel.support.*;
 import docking.widgets.table.GTable;
-import generic.test.TestUtils;
 import ghidra.app.cmd.data.CreateDataCmd;
+import ghidra.app.events.OpenProgramPluginEvent;
 import ghidra.app.events.ProgramSelectionPluginEvent;
+import ghidra.app.plugin.core.codebrowser.SelectEndpointsAction.RangeEndpoint;
 import ghidra.app.plugin.core.navigation.NextPrevAddressPlugin;
 import ghidra.app.plugin.core.symtable.SymbolTablePlugin;
 import ghidra.app.plugin.core.table.TableComponentProvider;
@@ -49,7 +50,10 @@ import ghidra.program.util.InteriorSelection;
 import ghidra.program.util.ProgramSelection;
 import ghidra.test.AbstractGhidraHeadedIntegrationTest;
 import ghidra.test.TestEnv;
+import ghidra.util.exception.CancelledException;
 import ghidra.util.table.AddressPreviewTableModel;
+import ghidra.util.table.GhidraProgramTableModel;
+import ghidra.util.task.TaskMonitor;
 
 public class CodeBrowserTest extends AbstractGhidraHeadedIntegrationTest {
 	private TestEnv env;
@@ -162,13 +166,14 @@ public class CodeBrowserTest extends AbstractGhidraHeadedIntegrationTest {
 		performAction(createTableAction, true);
 
 		TableComponentProvider<?> tableProvider =
-			waitForComponentProvider(tool.getToolFrame(), TableComponentProvider.class, 2000);
-		Object threadedPanel = TestUtils.getInstanceField("threadedPanel", tableProvider);
-		GTable table = (GTable) TestUtils.getInstanceField("table", threadedPanel);
-		ListSelectionModel selectionModel = table.getSelectionModel();
+			waitForComponentProvider(TableComponentProvider.class);
+		GhidraProgramTableModel<?> model = tableProvider.getModel();
+		waitForTableModel(model);
+		GTable table = tableProvider.getThreadedTablePanel().getTable();
 
 		// select all the rows
-		selectionModel.setSelectionInterval(0, table.getRowCount() - 1);
+		ListSelectionModel selectionModel = table.getSelectionModel();
+		runSwing(() -> selectionModel.setSelectionInterval(0, table.getRowCount() - 1));
 		AddressPreviewTableModel addressModel = (AddressPreviewTableModel) tableProvider.getModel();
 
 		// get a selection from the model and make sure it matches the original selection
@@ -182,6 +187,54 @@ public class CodeBrowserTest extends AbstractGhidraHeadedIntegrationTest {
 		}
 	}
 
+	@Test
+	public void testAddressRangeTableFromSelection() throws CancelledException {
+		AddressSet undefined = new AddressSet(program.getListing()
+				.getUndefinedRanges(program.getMemory().getAllInitializedAddressSet(), true,
+					TaskMonitor.DUMMY));
+		setSelection(undefined);
+		DockingActionIf createTableAction =
+			getAction(tool, CodeBrowserSelectionPlugin.CREATE_ADDRESS_RANGE_TABLE_ACTION_NAME);
+		performAction(createTableAction, true);
+		TableComponentProvider<?> tableProvider =
+			waitForComponentProvider(TableComponentProvider.class);
+		GhidraProgramTableModel<?> model = tableProvider.getModel();
+		waitForTableModel(model);
+		GTable table = tableProvider.getThreadedTablePanel().getTable();
+		assertEquals(7, table.getRowCount());
+
+		// select all the rows
+		ListSelectionModel selectionModel = table.getSelectionModel();
+		runSwing(() -> selectionModel.setSelectionInterval(0, table.getRowCount() - 1));
+		AddressRangeTableModel addressModel = (AddressRangeTableModel) tableProvider.getModel();
+
+		// get a selection from the model and make sure it matches the original selection
+		ProgramSelection tableProgramSelection =
+			addressModel.getProgramSelection(table.getSelectedRows());
+
+		AddressSet fromTable = new AddressSet();
+		tableProgramSelection.getAddressRanges().forEach(r -> fromTable.add(r));
+		assertEquals(fromTable, undefined);
+
+		DockingActionIf selectMinsAction = getAction(tool, "Select " + RangeEndpoint.MIN.name());
+		assertNotNull(selectMinsAction);
+		performAction(selectMinsAction, true);
+		ProgramSelection minSelect = getCurrentSelection();
+		assertEquals(7, minSelect.getNumAddresses());
+		for (AddressRange range : fromTable.getAddressRanges()) {
+			assertTrue(minSelect.contains(range.getMinAddress()));
+		}
+
+		DockingActionIf selectMaxesAction = getAction(tool, "Select " + RangeEndpoint.MAX.name());
+		assertNotNull(selectMaxesAction);
+		performAction(selectMaxesAction, true);
+		ProgramSelection maxSelect = getCurrentSelection();
+		assertEquals(7, maxSelect.getNumAddresses());
+		for (AddressRange range : fromTable.getAddressRanges()) {
+			assertTrue(maxSelect.contains(range.getMaxAddress()));
+		}
+	}
+
 	@Test
 	public void testSimpleDragToCreateSelection() {
 		ProgramSelection ps = dragToMakeSelection();
@@ -280,7 +333,7 @@ public class CodeBrowserTest extends AbstractGhidraHeadedIntegrationTest {
 
 		clickMouse(fp, 1, p2.x, p2.y, 1, DockingUtils.CONTROL_KEY_MODIFIER_MASK);
 
-// TODO		
+// TODO
 		ProgramSelection ps = getCurrentSelection();
 		assertEquals(26, ps.getNumAddresses());
 //		assertEquals(2, ps.getNumAddressRanges());
@@ -330,6 +383,9 @@ public class CodeBrowserTest extends AbstractGhidraHeadedIntegrationTest {
 
 		env.connectTools(tool, tool2);
 
+		// open same program in second tool - cannot rely on tool connection for this
+		tool2.firePluginEvent(new OpenProgramPluginEvent("Test", program));
+
 		cb.goToField(addr("0x1003a50"), "Bytes", 0, 4);
 		Point p1 = getCursorPoint();
 		cb.goToField(addr("0x1003a5e"), "Mnemonic", 0, 0, 2, false);
@@ -608,7 +664,7 @@ public class CodeBrowserTest extends AbstractGhidraHeadedIntegrationTest {
 	}
 
 	private void setView(AddressSet addrSet) {
-		runSwing(() -> cb.viewChanged(addrSet), true);
+		runSwing(() -> cb.setView(addrSet), true);
 	}
 
 	private void setSelection(final AddressSet addrSet) {
