@@ -1239,169 +1239,6 @@ public class CodeUnitIteratorTest extends AbstractGhidraHeadedIntegrationTest {
 		dtm.close();
 	}
 
-	@Test
-	public void testGetCompositeData() throws Exception {
-		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0, TaskMonitor.DUMMY, false);
-
-		Structure struct = new StructureDataType("struct_1", 100);
-		Structure struct2 = new StructureDataType("struct_2", 0);
-		Structure struct3 = new StructureDataType("struct_3", 0);
-		DataTypeManager dtm = new StandAloneDataTypeManager("dummyDTM");
-		int id = dtm.startTransaction("");
-
-		struct = (Structure) dtm.resolve(struct, null);
-		struct2 = (Structure) dtm.resolve(struct2, null);
-		struct3 = (Structure) dtm.resolve(struct3, null);
-
-		struct2.add(new ByteDataType());
-		struct2.add(new StringDataType(), 20);
-		struct2.add(new QWordDataType());
-		struct3.add(struct2);
-
-		struct.replace(0, struct2, struct2.getLength());
-		struct.replace(1, new StringDataType(), 10);
-
-		listing.createData(addr(0), struct, 0);
-
-		listing.createData(addr(300), struct2, 0);
-
-		listing.createData(addr(250), struct3, 0);
-		endTransaction();
-
-		DataIterator iter = listing.getCompositeData(true);
-		assertTrue(iter.hasNext());
-		Data d = iter.next();
-		assertNotNull(d);
-		assertEquals(addr(0), d.getMinAddress());
-		assertEquals(addr(99), d.getMaxAddress());
-
-		d = iter.next();
-		assertNotNull(d);
-		assertEquals(addr(250), d.getMinAddress());
-		assertEquals("struct_3", d.getDataType().getName());
-
-		d = iter.next();
-		assertNotNull(d);
-		assertEquals(addr(300), d.getMinAddress());
-		assertEquals(3, d.getNumComponents());
-
-		assertTrue(!iter.hasNext());
-		d = iter.next();
-		assertNull(d);
-		dtm.endTransaction(id, true);
-		dtm.close();
-	}
-
-	@Test
-	public void testGetCompositeDataStartingAt() throws Exception {
-		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0, TaskMonitor.DUMMY, false);
-
-		Structure struct = new StructureDataType("struct_1", 100);
-		Structure struct2 = new StructureDataType("struct_2", 0);
-		Structure struct3 = new StructureDataType("struct_3", 0);
-		DataTypeManager dtm = new StandAloneDataTypeManager("dummyDTM");
-		int id = dtm.startTransaction("");
-		struct = (Structure) dtm.resolve(struct, null);
-		struct2 = (Structure) dtm.resolve(struct2, null);
-		struct3 = (Structure) dtm.resolve(struct3, null);
-
-		struct2.add(new ByteDataType());
-		struct2.add(new StringDataType(), 20);
-		struct2.add(new QWordDataType());
-		struct3.add(struct2);
-
-		struct.replace(0, struct2, struct2.getLength());
-		struct.replace(1, new StringDataType(), 10);
-
-		listing.createData(addr(0), struct, 0);
-
-		listing.createData(addr(300), struct2, 0);
-
-		listing.createData(addr(250), struct3, 0);
-
-		Union union = new UnionDataType("union_1");
-		union.add(struct3);
-		union.add(struct2);
-
-		listing.createData(addr(600), union, 0);
-		endTransaction();
-
-		DataIterator iter = listing.getCompositeData(addr(275), true);
-		assertTrue(iter.hasNext());
-
-		Data d = iter.next();
-		assertNotNull(d);
-		assertEquals(addr(300), d.getMinAddress());
-
-		d = iter.next();
-		assertNotNull(d);
-		assertEquals(addr(600), d.getMinAddress());
-
-		assertTrue(!iter.hasNext());
-		assertNull(iter.next());
-		dtm.endTransaction(id, true);
-		dtm.close();
-
-	}
-
-	@Test
-	public void testGetCompositeDataInSet() throws Exception {
-		startTransaction();
-		mem.createInitializedBlock("test", addr(0), 1000, (byte) 0, TaskMonitor.DUMMY, false);
-
-		Structure struct = new StructureDataType("struct_1", 100);
-		Structure struct2 = new StructureDataType("struct_2", 0);
-		Structure struct3 = new StructureDataType("struct_3", 0);
-		DataTypeManager dtm = new StandAloneDataTypeManager("dummyDTM");
-		int id = dtm.startTransaction("");
-		struct = (Structure) dtm.resolve(struct, null);
-		struct2 = (Structure) dtm.resolve(struct2, null);
-		struct3 = (Structure) dtm.resolve(struct3, null);
-
-		struct2.add(new ByteDataType());
-		struct2.add(new StringDataType(), 20);
-		struct2.add(new QWordDataType());
-		struct3.add(struct2);
-
-		struct.replace(0, struct2, struct2.getLength());
-		struct.replace(1, new StringDataType(), 10);
-
-		listing.createData(addr(0), struct, 0);
-
-		listing.createData(addr(300), struct2, 0);
-
-		listing.createData(addr(450), struct3, 0);
-
-		Union union = new UnionDataType("union_1");
-		union.add(struct3);
-		union.add(struct2);
-
-		listing.createData(addr(800), union, 0);
-		endTransaction();
-
-		AddressSet set = new AddressSet();
-		set.addRange(addr(5), addr(10));
-		set.addRange(addr(100), addr(200));
-		set.addRange(addr(300), addr(320));
-		set.addRange(addr(400), addr(500));
-
-		DataIterator iter = listing.getCompositeData(set, true);
-		Data d = iter.next();
-		assertNotNull(d);
-		assertEquals(addr(300), d.getMinAddress());
-		d = iter.next();
-		assertNotNull(d);
-		assertEquals(addr(450), d.getMinAddress());
-
-		d = iter.next();
-		assertNull(d);
-		dtm.endTransaction(id, true);
-		dtm.close();
-
-	}
-
 	@Test
 	public void testGetDefinedDataIterator() throws Exception {
 		startTransaction();
