@@ -15,15 +15,19 @@
  */
 package ghidra.app.plugin.core.decompiler.taint.actions;
 
+import java.awt.event.InputEvent;
+import java.awt.event.KeyEvent;
+
+import docking.action.KeyBindingData;
 import ghidra.app.plugin.core.decompiler.taint.TaintPlugin;
-import ghidra.app.plugin.core.decompiler.taint.TaintState;
 import ghidra.app.plugin.core.decompiler.taint.TaintState.QueryType;
 
 public class TaintQueryCustomAction extends TaintAbstractQueryAction {
 
-	public TaintQueryCustomAction(TaintPlugin plugin, TaintState state) {
-		super(plugin, state, "CustomQuery", "Run custom taint query");
+	public TaintQueryCustomAction(TaintPlugin plugin) {
+		super(plugin, "CustomQuery", "Custom Taint Query", "Run custom taint query");
 		queryType = QueryType.CUSTOM;
+		setKeyBindingData(new KeyBindingData(KeyEvent.VK_Y, InputEvent.CTRL_DOWN_MASK));
 	}
 
 }
