@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -33,9 +33,9 @@ import ghidra.feature.vt.api.db.VTSessionDB;
 import ghidra.feature.vt.api.main.*;
 import ghidra.feature.vt.api.util.VTOptions;
 import ghidra.feature.vt.gui.plugin.*;
+import ghidra.feature.vt.gui.provider.markuptable.VTMarkupItemsTableProvider;
 import ghidra.feature.vt.gui.provider.matchtable.VTMatchTableModel;
 import ghidra.feature.vt.gui.provider.matchtable.VTMatchTableProvider;
-import ghidra.framework.plugintool.Plugin;
 import ghidra.framework.plugintool.PluginTool;
 import ghidra.program.model.listing.Program;
 import ghidra.test.AbstractGhidraHeadedIntegrationTest;
@@ -56,9 +56,10 @@ public class VTTestEnv extends TestEnv {
 
 	public VTTestEnv() throws Exception {
 
-		PluginTool tool = getTool();
-		tool.removePlugins(new Plugin[] { getPlugin(ProgramManagerPlugin.class) });
-		tool.addPlugin(VTPlugin.class.getName());
+		PluginTool pluignTool = getTool();
+		pluignTool.removePlugins(List.of(getPlugin(ProgramManagerPlugin.class)));
+		pluignTool.addPlugin(VTPlugin.class.getName());
+
 		plugin = getPlugin(VTPlugin.class);
 		controller = (VTController) getInstanceField("controller", plugin);
 		matchTableProvider = (VTMatchTableProvider) getInstanceField("matchesProvider", plugin);
@@ -238,7 +239,19 @@ public class VTTestEnv extends TestEnv {
 	}
 
 	public void focusMatchTable() {
-		runSwing(() -> matchTableProvider.getComponent().requestFocus());
+		runSwing(() -> matchTableProvider.requestFocus());
+	}
+
+	public VTMarkupItemsTableProvider getMarkupItemsProvider() {
+		return (VTMarkupItemsTableProvider) getInstanceField("markupProvider", plugin);
+	}
+
+	public void focusMarkupItemsTable() {
+		VTMarkupItemsTableProvider markupProvider = getMarkupItemsProvider();
+		runSwing(() -> {
+			markupProvider.toFront();
+			markupProvider.requestFocus();
+		});
 	}
 
 	public void triggerMatchTableDataChanged() {
@@ -250,4 +263,5 @@ public class VTTestEnv extends TestEnv {
 	public VTMatchTableProvider getMatchTableProvider() {
 		return matchTableProvider;
 	}
+
 }
