@@ -384,6 +384,12 @@ public abstract class AbstractDockingTest extends AbstractGuiTest {
 			return;
 		}
 
+		if (w instanceof DockingDialog dialog) {
+			DialogComponentProvider component = dialog.getDialogComponent();
+			close(component);
+			return;
+		}
+
 		boolean wait = !isOnlyFrame(w);
 		runSwing(() -> w.setVisible(false), wait);
 	}
@@ -984,6 +990,43 @@ public abstract class AbstractDockingTest extends AbstractGuiTest {
 		pressButtonByText(provider.getComponent(), buttonText, waitForCompletion);
 	}
 
+	/**
+	 * Finds the toggle button with the given name inside of the given container and then
+	 * gets the selected state of the button.
+	 * <p>
+	 * Note: this works for any instanceof {@link JToggleButton}, such as:
+	 * <ul>
+	 * 	<li>{@link JCheckBox}</li>
+	 *  <li>{@link JRadioButton}</li>
+	 * </ul>
+	 * as well as {@link EmptyBorderToggleButton}s.
+	 *
+	 * @param container a container that has the desired button as a descendant
+	 * @param buttonName the name of the button (you must set this on the button when it is
+	 *                   constructed; if there is no button with the given name found, then this
+	 *                   method will search for a button with the given text
+	 * @return true if the button is selected
+	 */
+	public static boolean isToggleButttonSelected(Container container, String buttonName) {
+		AbstractButton button = findAbstractButtonByName(container, buttonName);
+		if (button == null) {
+			button = findAbstractButtonByText(container, buttonName);
+		}
+		if (button == null) {
+			throw new AssertionError("Could not find button by name or text '" + buttonName + "'");
+		}
+
+		boolean isToggle =
+			(button instanceof JToggleButton) || (button instanceof EmptyBorderToggleButton);
+		if (!isToggle) {
+			throw new AssertionError(
+				"Found a button, but it is not a toggle button.  Text: '" + buttonName + "'");
+		}
+
+		AbstractButton finalButton = button;
+		return runSwing(() -> finalButton.isSelected());
+	}
+
 	/**
 	 * Finds the toggle button with the given name inside of the given container and then
 	 * ensures that the selected state of the button matches <code>selected</code>.
@@ -1037,7 +1080,7 @@ public abstract class AbstractDockingTest extends AbstractGuiTest {
 	 * @param selected true to toggle the button to selected; false for de-selected
 	 */
 	public static void setToggleButtonSelected(AbstractButton button, boolean selected) {
-		boolean isSelected = button.isSelected();
+		boolean isSelected = runSwing(() -> button.isSelected());
 		if (isSelected != selected) {
 			pressButton(button);
 		}
@@ -1349,7 +1392,7 @@ public abstract class AbstractDockingTest extends AbstractGuiTest {
 	 *
 	 * @param toggleAction the action
 	 * @param context the context for the action
-	 * @param selected true if the action is be be selected; false for not selected
+	 * @param selected true if the action is to be selected; false for not selected
 	 */
 	public static void setToggleActionSelected(ToggleDockingActionIf toggleAction,
 			ActionContext context, boolean selected) {
@@ -1362,7 +1405,7 @@ public abstract class AbstractDockingTest extends AbstractGuiTest {
 	 *
 	 * @param toggleAction the action
 	 * @param context the context for the action
-	 * @param selected true if the action is be be selected; false for not selected
+	 * @param selected true if the action is to be selected; false for not selected
 	 * @param wait true to wait for the action to finish; false to invoke later
 	 */
 	public static void setToggleActionSelected(ToggleDockingActionIf toggleAction,
@@ -2101,6 +2144,11 @@ public abstract class AbstractDockingTest extends AbstractGuiTest {
 				TimeUnit.NANOSECONDS));
 		*/
 		doWaitForTree(gTree);
+
+		// some client tree operations will launch tasks that wait for the tree and then call a 
+		// Swing task to run at some point after that.  waitForSwing() is not good enough for these,
+		// since the tree may be using a timer that has not yet expired.
+		waitForExpiringSwingTimers();
 	}
 
 	private static void doWaitForTree(GTree gTree) {
