@@ -4,9 +4,9 @@
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -42,6 +42,7 @@ public class FieldRangeQuery implements Query {
 	/**
 	 * @see ghidra.program.database.util.Query#matches(db.DBRecord)
 	 */
+	@Override
 	public boolean matches(DBRecord record) {
 		return (record.compareFieldTo(column, min) > 0) && (record.compareFieldTo(column, max) < 0);
 	}
